@@ -5,11 +5,30 @@ Test for methods of the Beam class.
 from math import isclose, nextafter
 
 import numpy as np
+import pytest
 
 from simplebeam import fix_ended, point, simple, udl
 
 
-def test_moment_curve():
+def check_expected_points(expected_points, actual_points, length):
+    """
+    Helper method to check that all expected points are found in the results.
+
+    :param expected_points: the expected points to find.
+    :param actual_points: the actual points to check.
+    :param length: the length of the beam.
+    """
+
+    for e in expected_points:
+        assert e in actual_points
+
+    # Check that there is a point at the nearest possible point to 0, and to l.
+    assert nextafter(0, length) in actual_points
+    assert nextafter(length, 0) in actual_points
+
+
+@pytest.mark.parametrize("fast", [(True), (False)])
+def test_moment_curve(fast):
     """
     Test the moment curve method.
 
@@ -30,25 +49,17 @@ def test_moment_curve():
         user_points + [nextafter(0, l), nextafter(l, 0)] + list(np.linspace(0, l, 101))
     )
 
-    x, y = beam.moment_curve(user_points=user_points, fast=False)
+    x, y = beam.moment_curve(user_points=user_points, fast=fast)
 
-    for e in expected_points:
-        assert e in x
-
-    assert nextafter(0, l) in x
-    assert nextafter(l, 0) in x
+    check_expected_points(expected_points=expected_points, actual_points=x, length=l)
 
     assert isclose(max(y), 0.125 * w * l**2)
 
     beam = fix_ended(length=l, loads=l1)
 
-    x, y = beam.moment_curve(user_points=user_points, fast=False)
+    x, y = beam.moment_curve(user_points=user_points, fast=fast)
 
-    for e in expected_points:
-        assert e in x
-
-    assert nextafter(0, l) in x
-    assert nextafter(l, 0) in x
+    check_expected_points(expected_points=expected_points, actual_points=x, length=l)
 
     assert isclose(max(y), (1 / 24) * w * l**2)
     assert isclose(min(y), -(1 / 12) * w * l**2)
@@ -58,82 +69,17 @@ def test_moment_curve():
 
     beam = simple(length=l, loads=l1)
 
-    x, y = beam.moment_curve(user_points=user_points, fast=False)
+    x, y = beam.moment_curve(user_points=user_points, fast=fast)
 
     assert isclose(max(y), P * l * 0.25)
     assert isclose(y[x.index(0.25 * l)], 0.5 * P * l * 0.25)
     assert isclose(y[x.index(0.75 * l)], 0.5 * P * l * 0.25)
 
-    for e in expected_points:
-        assert e in x
-
-    assert nextafter(0, l) in x
-    assert nextafter(l, 0) in x
+    check_expected_points(expected_points=expected_points, actual_points=x, length=l)
 
 
-def test_moment_curve_fast():
-    """
-    Test the moment curve method.
-
-    Note that because the underlying method that approximates the curve includes a
-    random choice of points, we will use the user_points function,
-    along with maximum and minimum checks to determine if the method is working well.
-    """
-
-    l = 4
-    w = 4
-
-    l1 = udl(magnitude=w)
-
-    beam = simple(length=l, loads=l1)
-
-    user_points = [l / 8, l / 3, l / 2]
-    expected_points = set(
-        user_points + [nextafter(0, l), nextafter(l, 0)] + list(np.linspace(0, l, 101))
-    )
-
-    x, y = beam.moment_curve(user_points=user_points)
-
-    for e in expected_points:
-        assert e in x
-
-    assert nextafter(0, l) in x
-    assert nextafter(l, 0) in x
-
-    assert isclose(max(y), 0.125 * w * l**2)
-
-    beam = fix_ended(length=l, loads=l1)
-
-    x, y = beam.moment_curve(user_points=user_points)
-
-    for e in expected_points:
-        assert e in x
-
-    assert nextafter(0, l) in x
-    assert nextafter(l, 0) in x
-
-    assert isclose(max(y), (1 / 24) * w * l**2)
-    assert isclose(min(y), -(1 / 12) * w * l**2)
-
-    P = 1
-    l1 = point(magnitude=P, position=l / 2)
-
-    beam = simple(length=l, loads=l1)
-
-    x, y = beam.moment_curve(user_points=user_points)
-
-    assert isclose(max(y), P * l * 0.25)
-    assert isclose(y[x.index(0.25 * l)], 0.5 * P * l * 0.25)
-    assert isclose(y[x.index(0.75 * l)], 0.5 * P * l * 0.25)
-
-    for e in expected_points:
-        assert e in x
-
-    assert nextafter(0, l) in x
-    assert nextafter(l, 0) in x
-
-
-def test_shear_curve():
+@pytest.mark.parametrize("fast", [(True), (False)])
+def test_shear_curve(fast):
     """
     Test the shear curve method.
 
@@ -154,23 +100,18 @@ def test_shear_curve():
         user_points + [nextafter(0, l), nextafter(l, 0)] + list(np.linspace(0, l, 101))
     )
 
-    x, y = beam.shear_curve(user_points=user_points, fast=False)
+    x, y = beam.shear_curve(user_points=user_points, fast=fast)
 
-    for e in expected_points:
-        assert e in x
-
-    assert nextafter(0, l) in x
-    assert nextafter(l, 0) in x
+    check_expected_points(expected_points, x, l)
 
     assert isclose(max(y), 0.5 * w * l)
     assert isclose(min(y), -0.5 * w * l)
 
     beam = fix_ended(length=l, loads=l1)
 
-    x, y = beam.shear_curve(user_points=user_points, fast=False)
+    x, y = beam.shear_curve(user_points=user_points, fast=fast)
 
-    for e in expected_points:
-        assert e in x
+    check_expected_points(expected_points=expected_points, actual_points=x, length=l)
 
     assert isclose(max(y), 0.5 * w * l)
     assert isclose(min(y), -0.5 * w * l)
@@ -183,7 +124,7 @@ def test_shear_curve():
 
     beam = simple(length=l, loads=l1)
 
-    x, y = beam.shear_curve(user_points=user_points, fast=False)
+    x, y = beam.shear_curve(user_points=user_points, fast=fast)
 
     assert isclose(max(y), 0.5 * P)
     assert isclose(min(y), -0.5 * P)
@@ -192,11 +133,7 @@ def test_shear_curve():
     assert isclose(y[x.index(0.25 * l)], 0.5 * P)
     assert isclose(y[x.index(0.75 * l)], -0.5 * P)
 
-    for e in expected_points:
-        assert e in x
-
-    assert nextafter(0, l) in x
-    assert nextafter(l, 0) in x
+    check_expected_points(expected_points, x, l)
 
 
 def test_shear_at_point():
